contexttools.is_component_with_time_signature_mark_attached
===========================================================

.. autofunction:: abjad.tools.contexttools.is_component_with_time_signature_mark_attached.is_component_with_time_signature_mark_attached
